@@ -16,7 +16,7 @@ from ..utils.model_handle import format_params_handle
 class LocationService:
 
     @staticmethod
-    def location_list(params, need_pagination=True, fields=("thread_id", "longitude", "latitude", "altitude")):
+    def location_list(params, need_pagination=True, fields=None):
         # 支持其他服务调用
         if not need_pagination:
             params = format_params_handle(
@@ -32,7 +32,10 @@ class LocationService:
                 return None, str(e)
             if not location_obj:
                 return [], None
-            return list(location_obj.values(*fields)), None
+            if fields:
+                return list(location_obj.values(*fields)), None
+
+            return list(location_obj.values()), None
 
         # 正常分页查询
         params = format_params_handle(
@@ -49,7 +52,10 @@ class LocationService:
         location_obj = location_obj.filter(**params)
         count = location_obj.count()
         location_set = location_obj.values()
+        if fields:
+            location_set = location_obj.values(*fields)
         finish_set = list(Paginator(location_set, size).page(page))
+
         return {"page": int(page), "size": int(size), "count": count, "list": finish_set}, None
 
     @staticmethod
